aboutsummaryrefslogtreecommitdiff
path: root/tests/test_helpers/mount_unmount.go
diff options
context:
space:
mode:
Diffstat (limited to 'tests/test_helpers/mount_unmount.go')
-rw-r--r--tests/test_helpers/mount_unmount.go7
1 files changed, 4 insertions, 3 deletions
diff --git a/tests/test_helpers/mount_unmount.go b/tests/test_helpers/mount_unmount.go
index afd33f1..46c64c9 100644
--- a/tests/test_helpers/mount_unmount.go
+++ b/tests/test_helpers/mount_unmount.go
@@ -242,11 +242,12 @@ func ListFds(pid int, prefix string) []string {
// fd was closed in the meantime
continue
}
- if strings.HasPrefix(target, "pipe:") || strings.HasPrefix(target, "anon_inode:[eventpoll]") {
+ if strings.HasPrefix(target, "pipe:") || strings.HasPrefix(target, "anon_inode:[eventpoll]") ||
+ strings.HasPrefix(target, "anon_inode:[pidfd]") {
// The Go runtime creates pipes on demand for splice(), which
// creates spurious test failures. Ignore all pipes.
// Also get rid of the "eventpoll" fd that is always there and not
// interesting.
filtered = append(filtered, target)
continue
}
@@ -242,11 +242,12 @@ func ListFds(pid int, prefix string) []string {
// The Go runtime creates pipes on demand for splice(), which
// creates spurious test failures. Ignore all pipes.
- // Also get rid of the "eventpoll" fd that is always there and not
- // interesting.
+ // Also get rid of the "eventpoll" and "pidfd" fds that are always there
+ // and not interesting.
filtered = append(filtered, target)
continue